You are viewing a plain text version of this content. The canonical link for it is here.
Posted to xap-commits@incubator.apache.org by jm...@apache.org on 2007/01/06 00:51:37 UTC

svn commit: r493256 [2/2] - in /incubator/xap/trunk: WebContent/examples/dataBinding/ WebContent/examples/demo/ WebContent/examples/urlResolution/ WebContent/examples/widgets/ src/xap/bridges/dojo/ src/xap/bridges/xap/

Modified: incubator/xap/trunk/WebContent/examples/widgets/radioButton.xal
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/WebContent/examples/widgets/radioButton.xal?view=diff&rev=493256&r1=493255&r2=493256
==============================================================================
--- incubator/xap/trunk/WebContent/examples/widgets/radioButton.xal (original)
+++ incubator/xap/trunk/WebContent/examples/widgets/radioButton.xal Fri Jan  5 16:51:35 2007
@@ -31,75 +31,75 @@
 	
 	<horizontalFlowPane width="825px">			
 		
-			<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Hello World!" 
+			<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Hello World!" 
 			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'text', 'Hello World!!!')" />
 			 
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="&lt;b&gt;Hear me roar!&lt;/b&gt;" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="&lt;b&gt;Hear me roar!&lt;/b&gt;" 
 			onCommand="mco:attributeSetter.setAttribute(testComponent, 'text', '&lt;b&gt;Hear me roar!!!&lt;/b&gt;')" />		 
 			 
 				
-			<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="textPlacementVertical = top" 
-				onCommand="mco:attributeSetter.setAttribute(testComponent, 'textPlacementVertical', 'top')" />	
+			<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="verticalTextToImagePlacement = top" 
+				onCommand="mco:attributeSetter.setAttribute(testComponent, 'verticalTextToImagePlacement', 'top')" />	
 	
-			<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="textPlacementVertical = bottom" 
-				onCommand="mco:attributeSetter.setAttribute(testComponent, 'textPlacementVertical', 'bottom')" />	
+			<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="verticalTextToImagePlacement = bottom" 
+				onCommand="mco:attributeSetter.setAttribute(testComponent, 'verticalTextToImagePlacement', 'bottom')" />	
 	
-			<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="textPlacementHorizontal = left" 
-				onCommand="mco:attributeSetter.setAttribute(testComponent, 'textPlacementHorizontal', 'left')" />	
+			<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="horizontalTextToImagePlacement = left" 
+				onCommand="mco:attributeSetter.setAttribute(testComponent, 'horizontalTextToImagePlacement', 'left')" />	
 	
-			<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="textPlacementHorizontal = right" 
-				onCommand="mco:attributeSetter.setAttribute(testComponent, 'textPlacementHorizontal', 'right')" />	 
+			<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="horizontalTextToImagePlacement = right" 
+				onCommand="mco:attributeSetter.setAttribute(testComponent, 'horizontalTextToImagePlacement', 'right')" />	 
 	
-			<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="alignHorizontal = left" 
-			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'alignHorizontal', 'left')" />	
+			<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="horizontalAlignment = left" 
+			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'horizontalAlignment', 'left')" />	
 	
-			<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="alignHorizontal = center" 
-			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'alignHorizontal', 'center')" />	
+			<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="horizontalAlignment = center" 
+			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'horizontalAlignment', 'center')" />	
 	
-			<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="alignHorizontal = right" 
-			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'alignHorizontal', 'right')" />
+			<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="horizontalAlignment = right" 
+			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'horizontalAlignment', 'right')" />
 			 
-			<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="alignVertical = top" 
-			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'alignVertical', 'top')" />	
+			<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="verticalAlignment = top" 
+			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'verticalAlignment', 'top')" />	
 	
-			<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="alignVertical = center" 
-			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'alignVertical', 'center')" />	
+			<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="verticalAlignment = center" 
+			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'verticalAlignment', 'center')" />	
 	
-			<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="alignVertical = bottom" 
-			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'alignVertical', 'bottom')" />
+			<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="verticalAlignment = bottom" 
+			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'verticalAlignment', 'bottom')" />
 			 
 			 
-			<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="set image over" 
+			<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="set image over" 
 			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'mouseOverImage', '../background.JPG')" />	 
 			 		 
-			<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="set image over selected" 
+			<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="set image over selected" 
 			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'mouseOverSelectedImage', '../background.JPG')" />	 
 			 
-			<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="set image pressed selected" 
+			<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="set image pressed selected" 
 			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'pressedSelectedImage', '../background.JPG')" />	 
 	
-			<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="set image pressed" 
+			<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="set image pressed" 
 			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'pressedImage', '../background.JPG')" />	 
 			 
-			<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="set image selected" 
+			<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="set image selected" 
 			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'selectedImage', '../background.JPG')" />	
 	
-			<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="set image" 
+			<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="set image" 
 			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'image', '../background.JPG')" />				 		 
 	
-			<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="richText = true" 
+			<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="richText = true" 
 			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'richText', 'true')" />			 
 	
-			<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="disabled = false" 
+			<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="disabled = false" 
 			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'disabled', 'false')" />	
 	
-			<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="disabled = true" 
+			<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="disabled = true" 
 			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'disabled', 'true')" />			 		 
 	
-			<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="selected = true" 
+			<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="selected = true" 
 			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'selected', 'true')" />		
 			 
-			<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="selected = false" 
+			<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="selected = false" 
 			 onCommand="mco:attributeSetter.setAttribute(testComponent, 'selected', 'false')" />		
 	
 		</horizontalFlowPane>	
@@ -110,63 +110,63 @@
 		 
 		
 		<!--
-	  <label width="400px" height="100px" alignHorizontal="center" alignVertical="top" text="HCenterVTop" textPlacementHorizontal="right" textPlacementVertical="bottom" />
-	  <label width="400px" height="100px" alignHorizontal="center" alignVertical="top" text="HCenterVTop" textPlacementHorizontal="left" textPlacementVertical="top" />		
-	  <label width="400px" height="100px" alignHorizontal="center" alignVertical="top" text="HCenterVTop" textPlacementHorizontal="left" textPlacementVertical="bottom" />		
-		
-		
-	  <label width="700px" height="100px" alignHorizontal="center" alignVertical="bottom" text="HCenter VBottom" />
-	  <label width="700px" height="100px" alignHorizontal="center" alignVertical="bottom" text="HCenter VBottom" textPlacementHorizontal="right" textPlacementVertical="top" />
-	  <label width="700px" height="100px" alignHorizontal="center" alignVertical="bottom" text="HCenter VBottom" textPlacementHorizontal="right" textPlacementVertical="bottom" />
-	  <label width="700px" height="100px" alignHorizontal="center" alignVertical="bottom" text="HCenter VBottom" textPlacementHorizontal="left" textPlacementVertical="top" />
-	  <label width="700px" height="100px" alignHorizontal="center" alignVertical="bottom" text="HCenter VBottom" textPlacementHorizontal="left" textPlacementVertical="bottom" />		
-	
-	  <label width="700px" height="100px" alignHorizontal="center" alignVertical="center" text="HCenter VCenter" />	  
-		<label width="700px" height="100px" alignHorizontal="center" alignVertical="center" text="HCenter VCenter" textPlacementHorizontal="right" textPlacementVertical="top" />
-	  <label width="700px" height="100px" alignHorizontal="center" alignVertical="center" text="HCenter VCenter" textPlacementHorizontal="right" textPlacementVertical="bottom" />
-	  <label width="700px" height="100px" alignHorizontal="center" alignVertical="center" text="HCenter VCenter" textPlacementHorizontal="left" textPlacementVertical="top" />
-	  <label width="700px" height="100px" alignHorizontal="center" alignVertical="center" text="HCenter VCenter" textPlacementHorizontal="left" textPlacementVertical="bottom" />		
-		
-	  <label width="400px" height="100px" alignHorizontal="right" alignVertical="top" text="HRight VTop" />		
-	  <label width="400px" height="100px" alignHorizontal="right" alignVertical="top" text="HRight VTop" textPlacementHorizontal="right" textPlacementVertical="top" />
-	  <label width="400px" height="100px" alignHorizontal="right" alignVertical="top" text="HRight VTop" textPlacementHorizontal="right" textPlacementVertical="bottom" />
-	  <label width="400px" height="100px" alignHorizontal="right" alignVertical="top" text="HRight VTop" textPlacementHorizontal="left" textPlacementVertical="top" />
-	  <label width="400px" height="100px" alignHorizontal="right" alignVertical="top" text="HRight VTop" textPlacementHorizontal="left" textPlacementVertical="bottom" />
-		
-		
-	  <label width="400px" height="100px" alignHorizontal="right" alignVertical="bottom" text="HRight VBottom" />
-	  <label width="400px" height="100px" alignHorizontal="right" alignVertical="bottom" text="HRight VBottom" textPlacementHorizontal="right" textPlacementVertical="top" />
-	  <label width="400px" height="100px" alignHorizontal="right" alignVertical="bottom" text="HRight VBottom" textPlacementHorizontal="right" textPlacementVertical="bottom" />
-	  <label width="400px" height="100px" alignHorizontal="right" alignVertical="bottom" text="HRight VBottom" textPlacementHorizontal="left" textPlacementVertical="top" />
-	  <label width="400px" height="100px" alignHorizontal="right" alignVertical="bottom" text="HRight VBottom" textPlacementHorizontal="left" textPlacementVertical="bottom" />		
+	  <label width="400px" height="100px" horizontalAlignment="center" verticalAlignment="top" text="HCenterVTop" horizontalTextToImagePlacement="right" verticalTextToImagePlacement="bottom" />
+	  <label width="400px" height="100px" horizontalAlignment="center" verticalAlignment="top" text="HCenterVTop" horizontalTextToImagePlacement="left" verticalTextToImagePlacement="top" />		
+	  <label width="400px" height="100px" horizontalAlignment="center" verticalAlignment="top" text="HCenterVTop" horizontalTextToImagePlacement="left" verticalTextToImagePlacement="bottom" />		
+		
+		
+	  <label width="700px" height="100px" horizontalAlignment="center" verticalAlignment="bottom" text="HCenter VBottom" />
+	  <label width="700px" height="100px" horizontalAlignment="center" verticalAlignment="bottom" text="HCenter VBottom" horizontalTextToImagePlacement="right" verticalTextToImagePlacement="top" />
+	  <label width="700px" height="100px" horizontalAlignment="center" verticalAlignment="bottom" text="HCenter VBottom" horizontalTextToImagePlacement="right" verticalTextToImagePlacement="bottom" />
+	  <label width="700px" height="100px" horizontalAlignment="center" verticalAlignment="bottom" text="HCenter VBottom" horizontalTextToImagePlacement="left" verticalTextToImagePlacement="top" />
+	  <label width="700px" height="100px" horizontalAlignment="center" verticalAlignment="bottom" text="HCenter VBottom" horizontalTextToImagePlacement="left" verticalTextToImagePlacement="bottom" />		
+	
+	  <label width="700px" height="100px" horizontalAlignment="center" verticalAlignment="center" text="HCenter VCenter" />	  
+		<label width="700px" height="100px" horizontalAlignment="center" verticalAlignment="center" text="HCenter VCenter" horizontalTextToImagePlacement="right" verticalTextToImagePlacement="top" />
+	  <label width="700px" height="100px" horizontalAlignment="center" verticalAlignment="center" text="HCenter VCenter" horizontalTextToImagePlacement="right" verticalTextToImagePlacement="bottom" />
+	  <label width="700px" height="100px" horizontalAlignment="center" verticalAlignment="center" text="HCenter VCenter" horizontalTextToImagePlacement="left" verticalTextToImagePlacement="top" />
+	  <label width="700px" height="100px" horizontalAlignment="center" verticalAlignment="center" text="HCenter VCenter" horizontalTextToImagePlacement="left" verticalTextToImagePlacement="bottom" />		
+		
+	  <label width="400px" height="100px" horizontalAlignment="right" verticalAlignment="top" text="HRight VTop" />		
+	  <label width="400px" height="100px" horizontalAlignment="right" verticalAlignment="top" text="HRight VTop" horizontalTextToImagePlacement="right" verticalTextToImagePlacement="top" />
+	  <label width="400px" height="100px" horizontalAlignment="right" verticalAlignment="top" text="HRight VTop" horizontalTextToImagePlacement="right" verticalTextToImagePlacement="bottom" />
+	  <label width="400px" height="100px" horizontalAlignment="right" verticalAlignment="top" text="HRight VTop" horizontalTextToImagePlacement="left" verticalTextToImagePlacement="top" />
+	  <label width="400px" height="100px" horizontalAlignment="right" verticalAlignment="top" text="HRight VTop" horizontalTextToImagePlacement="left" verticalTextToImagePlacement="bottom" />
+		
+		
+	  <label width="400px" height="100px" horizontalAlignment="right" verticalAlignment="bottom" text="HRight VBottom" />
+	  <label width="400px" height="100px" horizontalAlignment="right" verticalAlignment="bottom" text="HRight VBottom" horizontalTextToImagePlacement="right" verticalTextToImagePlacement="top" />
+	  <label width="400px" height="100px" horizontalAlignment="right" verticalAlignment="bottom" text="HRight VBottom" horizontalTextToImagePlacement="right" verticalTextToImagePlacement="bottom" />
+	  <label width="400px" height="100px" horizontalAlignment="right" verticalAlignment="bottom" text="HRight VBottom" horizontalTextToImagePlacement="left" verticalTextToImagePlacement="top" />
+	  <label width="400px" height="100px" horizontalAlignment="right" verticalAlignment="bottom" text="HRight VBottom" horizontalTextToImagePlacement="left" verticalTextToImagePlacement="bottom" />		
 
-	  <label width="400px" height="100px" alignHorizontal="right" alignVertical="center" text="HRight VCenter" />
-	  <label width="400px" height="100px" alignHorizontal="right" alignVertical="center" text="HRight VCenter" textPlacementHorizontal="right" textPlacementVertical="top" />
-	  <label width="400px" height="100px" alignHorizontal="right" alignVertical="center" text="HRight VCenter" textPlacementHorizontal="right" textPlacementVertical="bottom" />
-	  <label width="400px" height="100px" alignHorizontal="right" alignVertical="center" text="HRight VCenter" textPlacementHorizontal="left" textPlacementVertical="top" />
-	  <label width="400px" height="100px" alignHorizontal="right" alignVertical="center" text="HRight VCenter" textPlacementHorizontal="left" textPlacementVertical="bottom" />		
+	  <label width="400px" height="100px" horizontalAlignment="right" verticalAlignment="center" text="HRight VCenter" />
+	  <label width="400px" height="100px" horizontalAlignment="right" verticalAlignment="center" text="HRight VCenter" horizontalTextToImagePlacement="right" verticalTextToImagePlacement="top" />
+	  <label width="400px" height="100px" horizontalAlignment="right" verticalAlignment="center" text="HRight VCenter" horizontalTextToImagePlacement="right" verticalTextToImagePlacement="bottom" />
+	  <label width="400px" height="100px" horizontalAlignment="right" verticalAlignment="center" text="HRight VCenter" horizontalTextToImagePlacement="left" verticalTextToImagePlacement="top" />
+	  <label width="400px" height="100px" horizontalAlignment="right" verticalAlignment="center" text="HRight VCenter" horizontalTextToImagePlacement="left" verticalTextToImagePlacement="bottom" />		
 		
 		
-	  <label width="400px" height="100px" alignHorizontal="left" alignVertical="top" text="HLeft VTop" />	
-	  <label width="400px" height="100px" alignHorizontal="left" alignVertical="top" text="HLeft VTop" textPlacementHorizontal="right" textPlacementVertical="top" />
-	  <label width="400px" height="100px" alignHorizontal="left" alignVertical="top" text="HLeft VTop" textPlacementHorizontal="right" textPlacementVertical="bottom" />
-	  <label width="400px" height="100px" alignHorizontal="left" alignVertical="top" text="HLeft VTop" textPlacementHorizontal="left" textPlacementVertical="top" />
-	  <label width="400px" height="100px" alignHorizontal="left" alignVertical="top" text="HLeft VTop" textPlacementHorizontal="left" textPlacementVertical="bottom" />		
+	  <label width="400px" height="100px" horizontalAlignment="left" verticalAlignment="top" text="HLeft VTop" />	
+	  <label width="400px" height="100px" horizontalAlignment="left" verticalAlignment="top" text="HLeft VTop" horizontalTextToImagePlacement="right" verticalTextToImagePlacement="top" />
+	  <label width="400px" height="100px" horizontalAlignment="left" verticalAlignment="top" text="HLeft VTop" horizontalTextToImagePlacement="right" verticalTextToImagePlacement="bottom" />
+	  <label width="400px" height="100px" horizontalAlignment="left" verticalAlignment="top" text="HLeft VTop" horizontalTextToImagePlacement="left" verticalTextToImagePlacement="top" />
+	  <label width="400px" height="100px" horizontalAlignment="left" verticalAlignment="top" text="HLeft VTop" horizontalTextToImagePlacement="left" verticalTextToImagePlacement="bottom" />		
 
-	  <label width="400px" height="100px" alignHorizontal="left" alignVertical="bottom" text="HLeft VBottom" />		
-	  <label width="400px" height="100px" alignHorizontal="left" alignVertical="bottom" text="HLeft VBottom" textPlacementHorizontal="right" textPlacementVertical="top" />
-	  <label width="400px" height="100px" alignHorizontal="left" alignVertical="bottom" text="HLeft VBottom" textPlacementHorizontal="right" textPlacementVertical="bottom" />
-	  <label width="400px" height="100px" alignHorizontal="left" alignVertical="bottom" text="HLeft VBottom" textPlacementHorizontal="left" textPlacementVertical="top" />
-	  <label width="400px" height="100px" alignHorizontal="left" alignVertical="bottom" text="HLeft VBottom" textPlacementHorizontal="left" textPlacementVertical="bottom" />		
+	  <label width="400px" height="100px" horizontalAlignment="left" verticalAlignment="bottom" text="HLeft VBottom" />		
+	  <label width="400px" height="100px" horizontalAlignment="left" verticalAlignment="bottom" text="HLeft VBottom" horizontalTextToImagePlacement="right" verticalTextToImagePlacement="top" />
+	  <label width="400px" height="100px" horizontalAlignment="left" verticalAlignment="bottom" text="HLeft VBottom" horizontalTextToImagePlacement="right" verticalTextToImagePlacement="bottom" />
+	  <label width="400px" height="100px" horizontalAlignment="left" verticalAlignment="bottom" text="HLeft VBottom" horizontalTextToImagePlacement="left" verticalTextToImagePlacement="top" />
+	  <label width="400px" height="100px" horizontalAlignment="left" verticalAlignment="bottom" text="HLeft VBottom" horizontalTextToImagePlacement="left" verticalTextToImagePlacement="bottom" />		
 
-	  <label width="400px" height="100px" alignHorizontal="left" alignVertical="center" text="HLeft VCenter"/>		
-	  <label width="400px" height="100px" alignHorizontal="left" alignVertical="center" text="HLeft VCenter" textPlacementHorizontal="right" textPlacementVertical="top" />
-	  <label width="400px" height="100px" alignHorizontal="left" alignVertical="center" text="HLeft VCenter" textPlacementHorizontal="right" textPlacementVertical="bottom" />
-	  <label width="400px" height="100px" alignHorizontal="left" alignVertical="center" text="HLeft VCenter" textPlacementHorizontal="left" textPlacementVertical="top" />
-	  <label width="400px" height="100px" alignHorizontal="left" alignVertical="center" text="HLeft VCenter" textPlacementHorizontal="left" textPlacementVertical="bottom" />		
+	  <label width="400px" height="100px" horizontalAlignment="left" verticalAlignment="center" text="HLeft VCenter"/>		
+	  <label width="400px" height="100px" horizontalAlignment="left" verticalAlignment="center" text="HLeft VCenter" horizontalTextToImagePlacement="right" verticalTextToImagePlacement="top" />
+	  <label width="400px" height="100px" horizontalAlignment="left" verticalAlignment="center" text="HLeft VCenter" horizontalTextToImagePlacement="right" verticalTextToImagePlacement="bottom" />
+	  <label width="400px" height="100px" horizontalAlignment="left" verticalAlignment="center" text="HLeft VCenter" horizontalTextToImagePlacement="left" verticalTextToImagePlacement="top" />
+	  <label width="400px" height="100px" horizontalAlignment="left" verticalAlignment="center" text="HLeft VCenter" horizontalTextToImagePlacement="left" verticalTextToImagePlacement="bottom" />		
 
-	  <label width="400px" height="100px" alignHorizontal="left" alignVertical="center" text="HLeft VCenter" textPlacementHorizontal="right"/>
-	  <label width="400px" height="100px" alignHorizontal="left" alignVertical="center" text="HLeft VCenter" textPlacementHorizontal="left"/>	
+	  <label width="400px" height="100px" horizontalAlignment="left" verticalAlignment="center" text="HLeft VCenter" horizontalTextToImagePlacement="right"/>
+	  <label width="400px" height="100px" horizontalAlignment="left" verticalAlignment="center" text="HLeft VCenter" horizontalTextToImagePlacement="left"/>	
 		
 		-->
 		

Modified: incubator/xap/trunk/WebContent/examples/widgets/standardButtons.xal
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/WebContent/examples/widgets/standardButtons.xal?view=diff&rev=493256&r1=493255&r2=493256
==============================================================================
--- incubator/xap/trunk/WebContent/examples/widgets/standardButtons.xal (original)
+++ incubator/xap/trunk/WebContent/examples/widgets/standardButtons.xal Fri Jan  5 16:51:35 2007
@@ -1,4 +1,4 @@
-<verticalBoxPane width="825px" xmlns="http://openxal.org/ui" align="left">
+<verticalBoxPane width="825px" xmlns="http://openxal.org/ui" alignment="left">
 <horizontalFlowPane width="825px" xmlns="http://openxal.org/ui">
 	<label width="825px" height="25px" text="Standard tests:" fontWeight="bold"/>
 

Modified: incubator/xap/trunk/WebContent/examples/widgets/table.xal
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/WebContent/examples/widgets/table.xal?view=diff&rev=493256&r1=493255&r2=493256
==============================================================================
--- incubator/xap/trunk/WebContent/examples/widgets/table.xal (original)
+++ incubator/xap/trunk/WebContent/examples/widgets/table.xal Fri Jan  5 16:51:35 2007
@@ -118,31 +118,31 @@
 	<horizontalBoxPane>
 
 	<verticalBoxPane>
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Start table updating" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Start table updating" 
 			onCommand="mco:tableMco.startUpdates(testComponent)" />
 		
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Stop table updating" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Stop table updating" 
 			onCommand="mco:tableMco.stopUpdates(testComponent)" />
 		
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Add basic row" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Add basic row" 
 			onCommand="macro:addRow.execute()" />
 		
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Add Branches" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Add Branches" 
 			onCommand="macro:branch.execute()" />
 		
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Insert Into Branch" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Insert Into Branch" 
 			onCommand="macro:intoBranch.execute()" />
 		
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Remove Row" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Remove Row" 
 			onCommand="macro:removeRow.execute()" />
 		
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Remove All Rows" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Remove All Rows" 
 			onCommand="macro:removeAllRows.execute()" />
 
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Remove Branch" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Remove Branch" 
 			onCommand="macro:removeBranch.execute()" />
 
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Add Column" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Add Column" 
 			onCommand="macro:addColumn.execute()" />
 		 
 	

Modified: incubator/xap/trunk/WebContent/examples/widgets/textArea.xal
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/WebContent/examples/widgets/textArea.xal?view=diff&rev=493256&r1=493255&r2=493256
==============================================================================
--- incubator/xap/trunk/WebContent/examples/widgets/textArea.xal (original)
+++ incubator/xap/trunk/WebContent/examples/widgets/textArea.xal Fri Jan  5 16:51:35 2007
@@ -43,7 +43,7 @@
 		<xm:append select="/ui">
 				<xal:textArea width="200px" 
 					id="testComponent"
-					alignHorizontal="right" alignVertical="center"
+					horizontalAlignment="right" verticalAlignment="center"
 					onActiveGained="mco:attributeSetter.reportEvent(event)"
 					onActiveLost="mco:attributeSetter.reportEvent(event)"
 					onBeforeActiveLost="mco:attributeSetter.reportEvent(event)"

Modified: incubator/xap/trunk/WebContent/examples/widgets/tree.xal
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/WebContent/examples/widgets/tree.xal?view=diff&rev=493256&r1=493255&r2=493256
==============================================================================
--- incubator/xap/trunk/WebContent/examples/widgets/tree.xal (original)
+++ incubator/xap/trunk/WebContent/examples/widgets/tree.xal Fri Jan  5 16:51:35 2007
@@ -113,28 +113,28 @@
 	<horizontalBoxPane>
 
 	<verticalBoxPane>
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Start table updating" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Start table updating" 
 			onCommand="mco:tableMco.startUpdates(testComponent)" />
 		
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Stop table updating" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Stop table updating" 
 			onCommand="mco:tableMco.stopUpdates(testComponent)" />
 		
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Add basic row" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Add basic row" 
 			onCommand="macro:addRow.execute()" />
 		
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Add Branches" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Add Branches" 
 			onCommand="macro:branch.execute()" />
 		
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Insert Into Branch" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Insert Into Branch" 
 			onCommand="macro:intoBranch.execute()" />
 		
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Remove Row" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Remove Row" 
 			onCommand="macro:removeRow.execute()" />
 		
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Remove Branch" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Remove Branch" 
 			onCommand="macro:removeBranch.execute()" />
 
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Add Column" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Add Column" 
 			onCommand="macro:addColumn.execute()" />
 		 
 	

Modified: incubator/xap/trunk/WebContent/examples/widgets/treeTable.xal
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/WebContent/examples/widgets/treeTable.xal?view=diff&rev=493256&r1=493255&r2=493256
==============================================================================
--- incubator/xap/trunk/WebContent/examples/widgets/treeTable.xal (original)
+++ incubator/xap/trunk/WebContent/examples/widgets/treeTable.xal Fri Jan  5 16:51:35 2007
@@ -112,28 +112,28 @@
 	<horizontalBoxPane>
 
 	<verticalBoxPane>
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Start table updating" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Start table updating" 
 			onCommand="mco:tableMco.startUpdates(testComponent)" />
 		
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Stop table updating" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Stop table updating" 
 			onCommand="mco:tableMco.stopUpdates(testComponent)" />
 		
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Add basic row" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Add basic row" 
 			onCommand="macro:addRow.execute()" />
 		
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Add Branches" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Add Branches" 
 			onCommand="macro:branch.execute()" />
 		
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Insert Into Branch" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Insert Into Branch" 
 			onCommand="macro:intoBranch.execute()" />
 		
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Remove Row" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Remove Row" 
 			onCommand="macro:removeRow.execute()" />
 		
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Remove Branch" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Remove Branch" 
 			onCommand="macro:removeBranch.execute()" />
 
-		<button width="200px" height="50px" alignHorizontal="center" alignVertical="center" text="Add Column" 
+		<button width="200px" height="50px" horizontalAlignment="center" verticalAlignment="center" text="Add Column" 
 			onCommand="macro:addColumn.execute()" />
 		 
 	

Modified: incubator/xap/trunk/WebContent/examples/widgets/verticalBoxPane.xal
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/WebContent/examples/widgets/verticalBoxPane.xal?view=diff&rev=493256&r1=493255&r2=493256
==============================================================================
--- incubator/xap/trunk/WebContent/examples/widgets/verticalBoxPane.xal (original)
+++ incubator/xap/trunk/WebContent/examples/widgets/verticalBoxPane.xal Fri Jan  5 16:51:35 2007
@@ -31,24 +31,24 @@
 
 
 		<xal:button width="200px" height="25px" 
-			text="align -> center"
+			text="alignment -> center"
 			onCommand="mco:attributeSetter.setAttribute(testComponent,
-				'align' ,'center')"/>
+				'alignment' ,'center')"/>
 				
 		<xal:button width="200px" height="25px" 
-			text="align -> start"
+			text="alignment -> start"
 			onCommand="mco:attributeSetter.setAttribute(testComponent,
-				'align' ,'start')"/>
+				'alignment' ,'start')"/>
 				
 		<xal:button width="200px" height="25px" 
-			text="align -> end"
+			text="alignment -> end"
 			onCommand="mco:attributeSetter.setAttribute(testComponent,
-				'align' ,'end')"/>
+				'alignment' ,'end')"/>
 				
 		<xal:button width="200px" height="25px" 
-			text="align -> stretch"
+			text="alignment -> stretch"
 			onCommand="mco:attributeSetter.setAttribute(testComponent,
-				'align' ,'stretch')"/>
+				'alignment' ,'stretch')"/>
 
 		<xal:button width="200px" height="25px" 
 			text="height -> 30px"
@@ -94,17 +94,17 @@
 		<xal:verticalBoxPane width="200px" height="500px" backgroundColor="black"
 			id="testComponent">
 			
-			<xal:freePane flex="3" width="110px" height="20px" backgroundColor="red" id="redComponent">
-				<label text="flex:3 width:110" x="0" y="0" />
+			<xal:freePane boxFlex="3" width="110px" height="20px" backgroundColor="red" id="redComponent">
+				<label text="boxFlex:3 width:110" x="0" y="0" />
 			</xal:freePane>
-			<xal:freePane flex="4" width="120px" height="20px" backgroundColor="green" id="greenComponent">
-				<label text="flex:4 width:120" x="0" y="0" />
+			<xal:freePane boxFlex="4" width="120px" height="20px" backgroundColor="green" id="greenComponent">
+				<label text="boxFlex:4 width:120" x="0" y="0" />
 			</xal:freePane>
-			<xal:freePane flex="1" width="150px" height="20px" backgroundColor="yellow" id="yellowComponent">
-				<label text="flex:1 width:150 Debug-Mon Nov 06 2006 14:29:05 GMT-0500 (Eastern Standard Time) (xap.taghandling.PluginRegistryImpl): Add tag mapping:binding:xap.data.bridge.BindingBridge" x="0" y="0" />
+			<xal:freePane boxFlex="1" width="150px" height="20px" backgroundColor="yellow" id="yellowComponent">
+				<label text="boxFlex:1 width:150 Debug-Mon Nov 06 2006 14:29:05 GMT-0500 (Eastern Standard Time) (xap.taghandling.PluginRegistryImpl): Add tag mapping:binding:xap.data.bridge.BindingBridge" x="0" y="0" />
 			</xal:freePane>
 			<xal:freePane width="140px" height="20px" backgroundColor="blue" id="blueComponent">
-				<label text="flex:null width:140" x="0" y="0" />
+				<label text="boxFlex:null width:140" x="0" y="0" />
 			</xal:freePane>			
 		</xal:verticalBoxPane> 
 </horizontalBoxPane>

Modified: incubator/xap/trunk/WebContent/examples/widgets/verticalPanelExample.xal
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/WebContent/examples/widgets/verticalPanelExample.xal?view=diff&rev=493256&r1=493255&r2=493256
==============================================================================
--- incubator/xap/trunk/WebContent/examples/widgets/verticalPanelExample.xal (original)
+++ incubator/xap/trunk/WebContent/examples/widgets/verticalPanelExample.xal Fri Jan  5 16:51:35 2007
@@ -33,7 +33,7 @@
 
 			
 
-		<xal:verticalBoxPane y="250px" width="200px" height="200px" borderWidth="1" borderStyle="solid" borderColor="black" align="stretch">
+		<xal:verticalBoxPane y="250px" width="200px" height="200px" borderWidth="1" borderStyle="solid" borderColor="black" alignment="stretch">
 
 		<xal:freePane width="100" height="20" backgroundColor="red"/>
 		<xal:freePane width="100" height="20" backgroundColor="green"/>
@@ -43,7 +43,7 @@
 
 
 
-		<xal:verticalBoxPane x="250px" y="250px" width="200px" height="200px" borderWidth="1" borderStyle="solid" borderColor="black" align="end">
+		<xal:verticalBoxPane x="250px" y="250px" width="200px" height="200px" borderWidth="1" borderStyle="solid" borderColor="black" alignment="end">
 
 		<xal:freePane width="100" height="20" backgroundColor="red"/>
 		<xal:freePane width="100" height="20" backgroundColor="green"/>

Modified: incubator/xap/trunk/src/xap/bridges/dojo/BorderPanelBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/dojo/BorderPanelBridge.js?view=diff&rev=493256&r1=493255&r2=493256
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/dojo/BorderPanelBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/dojo/BorderPanelBridge.js Fri Jan  5 16:51:35 2007
@@ -76,15 +76,15 @@
  * No new dynamic attributes
  */
 xap.bridges.dojo.BorderPanelBridge.prototype.getNewAllowedAttributes = function(){
-	return ["gapHorizontal", "gapVertical"];
+	return ["horizontalGap", "verticalGap"];
 }	
 
-xap.bridges.dojo.BorderPanelBridge.prototype.setGapHorizontalAttribute = function(value) {
+xap.bridges.dojo.BorderPanelBridge.prototype.setHorizontalGapAttribute = function(value) {
 	this.getPeer().setGapHorizontal(value);
 }
 
 
-xap.bridges.dojo.BorderPanelBridge.prototype.setGapVerticalAttribute = function(value) {
+xap.bridges.dojo.BorderPanelBridge.prototype.setVerticalGapAttribute = function(value) {
 	this.getPeer().setGapVertical(value);
 }
 

Modified: incubator/xap/trunk/src/xap/bridges/dojo/CellBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/dojo/CellBridge.js?view=diff&rev=493256&r1=493255&r2=493256
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/dojo/CellBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/dojo/CellBridge.js Fri Jan  5 16:51:35 2007
@@ -38,7 +38,7 @@
 
 
 xap.bridges.dojo.CellBridge.prototype.getNewAllowedAttributes = function() {
-	return ["text", "image", "backgroundColor", "alignHorizontal"];
+	return ["text", "image", "backgroundColor", "horizontalAlignment"];
 }	
 
 xap.bridges.dojo.CellBridge.prototype.setTextAttribute = function(text) {
@@ -59,7 +59,8 @@
 		this._domNode.parentNode.style.backgroundColor = value ;
 }
 
-xap.bridges.dojo.CellBridge.prototype.setAlignHorizontalAttribute = function(value){
+/** XML attribute set method for "horizontalAlignment" */
+xap.bridges.dojo.CellBridge.prototype.setHorizontalAlignmentAttribute = function(value){
 	// we need to set the attribute of our parent since we're only a lowly span
 	this._domNode.style.textAlign = value;
 	if ( this._domNode.parentNode )

Modified: incubator/xap/trunk/src/xap/bridges/dojo/GridPanelBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/dojo/GridPanelBridge.js?view=diff&rev=493256&r1=493255&r2=493256
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/dojo/GridPanelBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/dojo/GridPanelBridge.js Fri Jan  5 16:51:35 2007
@@ -63,24 +63,34 @@
 	};
 	
 	var element = childHandler.getElement();
-	var columnSpan= element.getAttribute("columnSpan");
+	var columnSpan= element.getAttribute("gridColumnSpan");
 	if (columnSpan){
 		constraints._columnSpan = parseInt(columnSpan);
 	}
 	
-	var rowSpan = element.getAttribute("rowSpan");
+	var rowSpan = element.getAttribute("gridRowSpan");
 	if (rowSpan){
 		constraints._rowSpan = parseInt(rowSpan);
 	}
 	
-	var hAlign = element.getAttribute("hAlign");
+	var hAlign = element.getAttribute("gridHorizontalAlignment");
 	if (hAlign){
 		constraints._hAlign = hAlign;
 	}
 	
-	var vAlign = element.getAttribute("vAlign");
+	var vAlign = element.getAttribute("gridVerticalAlignment");
 	if (vAlign){
 		constraints._vAlign = vAlign;
+	}
+	
+	var vGrabSpace = element.getAttribute("gridVerticalGrabSpace");
+	if (vGrabSpace) {
+	    constraints._vGrabSpace = (vGrabSpace == "true");
+	}
+	
+	var hGrabSpace = element.getAttribute("gridHorizontalGrabSpace");
+	if (hGrabSpace) {
+	    constraints._hGrabSpace = (hGrabSpace == "true");
 	}
 	
 	var childPeer = this.getDojoWidgetPeer(childHandler);

Modified: incubator/xap/trunk/src/xap/bridges/dojo/HorizontalFlowPaneBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/dojo/HorizontalFlowPaneBridge.js?view=diff&rev=493256&r1=493255&r2=493256
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/dojo/HorizontalFlowPaneBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/dojo/HorizontalFlowPaneBridge.js Fri Jan  5 16:51:35 2007
@@ -62,19 +62,19 @@
  * No new dynamic attributes
  */
 xap.bridges.dojo.HorizontalFlowPaneBridge.prototype.getNewAllowedAttributes = function(){
-	return ["gapHorizontal", "gapVertical", "align"];
+	return ["horizontalGap", "verticalGap", "alignment"];
 }	
 
-xap.bridges.dojo.HorizontalFlowPaneBridge.prototype.setGapHorizontalAttribute = function(value) {
+xap.bridges.dojo.HorizontalFlowPaneBridge.prototype.setHorizontalGapAttribute = function(value) {
 	this.getPeer().setGapHorizontal(value);
 }
 
 
-xap.bridges.dojo.HorizontalFlowPaneBridge.prototype.setGapVerticalAttribute = function(value) {
+xap.bridges.dojo.HorizontalFlowPaneBridge.prototype.setVerticalGapAttribute = function(value) {
 	this.getPeer().setGapVertical(value);
 }
 
-xap.bridges.dojo.HorizontalFlowPaneBridge.prototype.setAlignAttribute = function(value) {
+xap.bridges.dojo.HorizontalFlowPaneBridge.prototype.setAlignmentAttribute = function(value) {
 	this.getPeer().setAlign(value);
 }
 

Modified: incubator/xap/trunk/src/xap/bridges/dojo/HorizontalPanelBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/dojo/HorizontalPanelBridge.js?view=diff&rev=493256&r1=493255&r2=493256
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/dojo/TextFieldBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/dojo/TextFieldBridge.js Fri Jan  5 16:51:35 2007
@@ -77,7 +77,7 @@
  */
 xap.bridges.dojo.TextFieldBridge.prototype.getNewAllowedAttributes = function(){
 	return ["text","maxLength","selectable",
-				"editable", "alignVertical","alignHorizontal"
+				"editable", "verticalAlignment","horizontalAlignment"
 			];
 }	
 
@@ -177,11 +177,11 @@
 }	
 
 
-xap.bridges.dojo.TextFieldBridge.prototype.setAlignHorizontalAttribute = function(direction) {
+xap.bridges.dojo.TextFieldBridge.prototype.setHorizontalAlignmentAttribute = function(direction) {
 	xap.bridges.basic.AbstractWidgetBridge.prototype.setTextAlignAttribute.call(this,direction) ;
 }
   
-xap.bridges.dojo.TextFieldBridge.prototype.setAlignVerticalAttribute = function(direction) {
+xap.bridges.dojo.TextFieldBridge.prototype.setVerticalAlignmentAttribute = function(direction) {
 	if (direction == "top" || direction == "bottom" || direction == "center") {
 		direction = ((direction == "center") ? "middle" : direction ) ;
 		var vAlignmentObj = {verticalAlign: direction } ;

Modified: incubator/xap/trunk/src/xap/bridges/dojo/VerticalPanelBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/dojo/VerticalPanelBridge.js?view=diff&rev=493256&r1=493255&r2=493256
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/xap/LabelBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/xap/LabelBridge.js Fri Jan  5 16:51:35 2007
@@ -60,16 +60,16 @@
 }
 
 xap.bridges.xap.LabelBridge.prototype.getNewAllowedAttributes = function() {
-	return ["alignHorizontal", "alignVertical", "autoWrap", "image", 
+	return ["horizontalAlignment", "verticalAlignment", "autoWrap", "image", 
 		"backgroundImage", "disabledImage", "imageHeight", "imageWidth", "richText", 
-		"selectable", "text", "textPlacementHorizontal", "textPlacementVertical"];
+		"selectable", "text", "horizontalTextToImagePlacement", "verticalTextToImagePlacement"];
 }
 
-xap.bridges.xap.LabelBridge.prototype.setAlignHorizontalAttribute = function(alignment) {
+xap.bridges.xap.LabelBridge.prototype.setHorizontalAlignmentAttribute = function(alignment) {
 	this.getPeer().setAlignHorizontal(alignment);
 }
 
-xap.bridges.xap.LabelBridge.prototype.setAlignVerticalAttribute = function(alignment) {
+xap.bridges.xap.LabelBridge.prototype.setVerticalAlignmentAttribute = function(alignment) {
 	this.getPeer().setAlignVertical(alignment);
 }
 
@@ -124,11 +124,11 @@
 	this.getPeer().setText(text);
 }
 
-xap.bridges.xap.LabelBridge.prototype.setTextPlacementHorizontalAttribute = function(alignment) {
+xap.bridges.xap.LabelBridge.prototype.setHorizontalTextToImagePlacementAttribute = function(alignment) {
 	this.getPeer().setTextPlacementHorizontal(alignment);
 }
 
-xap.bridges.xap.LabelBridge.prototype.setTextPlacementVerticalAttribute = function(alignment) {
+xap.bridges.xap.LabelBridge.prototype.setVerticalTextToImagePlacementAttribute = function(alignment) {
 	this.getPeer().setTextPlacementVertical(alignment);
 }
--- incubator/xap/trunk/src/xap/bridges/dojo/HorizontalPanelBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/dojo/HorizontalPanelBridge.js Fri Jan  5 16:51:35 2007
@@ -60,15 +60,15 @@
  */ 
  
 xap.bridges.dojo.HorizontalPanelBridge.prototype.getNewAllowedAttributes = function(){
-	return ["align","pack"];
+	return ["alignment","pack"];
 }	
 
-/** XML attribute set method for "align" */
-xap.bridges.dojo.HorizontalPanelBridge.prototype.setAlignAttribute = function(value){
+/** XML attribute set method for "alignment" */
+xap.bridges.dojo.HorizontalPanelBridge.prototype.setAlignmentAttribute = function(value){
 	this.getPeer().setAlign(value);
 }
 
-/** XML attribute set method for "align" */
+/** XML attribute set method for "pack" */
 xap.bridges.dojo.HorizontalPanelBridge.prototype.setPackAttribute = function(value){
 	this.getPeer().setPack(value);
 }
@@ -77,7 +77,7 @@
 xap.bridges.dojo.HorizontalPanelBridge.prototype.addChild = function(childHandler, index) {
 	var element = childHandler.getElement();
 
-	var flex = element.getAttribute("flex");
+	var flex = element.getAttribute("boxFlex");
 	var flexInt = 1;
 	if (flex) {
 		flexInt= parseInt(flex);

Modified: incubator/xap/trunk/src/xap/bridges/dojo/TextFieldBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/dojo/TextFieldBridge.js?view=diff&rev=493256&r1=493255&r2=493256
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/dojo/VerticalPanelBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/dojo/VerticalPanelBridge.js Fri Jan  5 16:51:35 2007
@@ -60,11 +60,11 @@
  
  
 xap.bridges.dojo.VerticalPanelBridge.prototype.getNewAllowedAttributes = function(){
-	return ["align", "pack"];
+	return ["alignment", "pack"];
 }	
 
-/** XML attribute set method for "align" */
-xap.bridges.dojo.VerticalPanelBridge.prototype.setAlignAttribute = function(value){
+/** XML attribute set method for "alignment" */
+xap.bridges.dojo.VerticalPanelBridge.prototype.setAlignmentAttribute = function(value){
 	this.getPeer().setAlign(value);
 }
 
@@ -76,7 +76,7 @@
 xap.bridges.dojo.VerticalPanelBridge.prototype.addChild = function(childHandler, index) {
 	var element = childHandler.getElement();
 
-	var flex = element.getAttribute("flex");
+	var flex = element.getAttribute("boxFlex");
 	var flexInt = 1;
 	if (flex) {
 		flexInt= parseInt(flex);

Modified: incubator/xap/trunk/src/xap/bridges/xap/LabelBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/xap/LabelBridge.js?view=diff&rev=493256&r1=493255&r2=493256
==============================================================================